# Wheat ![CI status](http://git.chancefocus.com/transaction/base/chance-wheat/badges/master/build.svg)

Wheat is a Python library for generating python project.

## Installation

### Requirements
* Python 2.7 and up

`$ pip install wheat`

## Usage

```bash
wheat

> Enter your project name:
> Enter your name:
> Enter the output dir:

> Creating Directories
> Generating Files
> Initialization Finished
> Running checks
> Successfully create PROJECT at ...
```

## Development
```
$ virtualenv wheat
$ . wheat/bin/activate
$ pip install -e .
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)
